# PyTorch Lightning Spells

[![CircleCI](https://circleci.com/gh/veritable-tech/pytorch-lightning-spells/tree/master.svg?style=svg)](https://circleci.com/gh/veritable-tech/pytorch-lightning-spells/tree/master) [![Documentation Status](https://readthedocs.org/projects/pytorch-lightning-spells/badge/?version=latest)](https://pytorch-lightning-spells.readthedocs.io/en/latest/?badge=latest)

Some useful plugins for [PyTorch Lightning](https://github.com/PyTorchLightning/pytorch-lightning).

[Documentation](https://pytorch-lightning-spells.readthedocs.io/)
